==> zio-aws-route53recoverycontrolconfig_2.12-5.17.126.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/DescribeSafetyRuleRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeSafetyRuleRequest(safetyRuleArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest = {
    import DescribeSafetyRuleRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest
      .builder()
      .safetyRuleArn(__string.unwrap(safetyRuleArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest
      .wrap(buildAwsValue())
}
object DescribeSafetyRuleRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DescribeSafetyRuleRequest(safetyRuleArn)
    def safetyRuleArn: __string
    def getSafetyRuleArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(safetyRuleArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest.ReadOnly {
    override val safetyRuleArn: __string =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__string(impl.safetyRuleArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest
  ): zio.aws.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_2.13-5.17.201.2-sources.jar: zio/aws/route53recoverycontrolconfig/model/DescribeSafetyRuleRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeSafetyRuleRequest(safetyRuleArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest = {
    import DescribeSafetyRuleRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest
      .builder()
      .safetyRuleArn(safetyRuleArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest
      .wrap(buildAwsValue())
}
object DescribeSafetyRuleRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DescribeSafetyRuleRequest(safetyRuleArn)
    def safetyRuleArn: __string
    def getSafetyRuleArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(safetyRuleArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest.ReadOnly {
    override val safetyRuleArn: __string = impl.safetyRuleArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest
  ): zio.aws.route53recoverycontrolconfig.model.DescribeSafetyRuleRequest.ReadOnly =
    new Wrapper(impl)
}
